#!/bin/bash

make_tidy_autogen() {
    make tidy
    make autogen
    if [[ $(git status --short) != "" ]]; then
        git add -A
        git commit -m "Run make tidy and make autogen"
    fi
}

write_changelog() {
    file="CHANGELOG.md"
    echo '<!-- Note: This file is autogenerated based on files in docs/releases. Run hack/release.sh to update -->' > ${file}
    echo "" >> ${file}
    echo "# Changelog" >> ${file}
    echo "" >> ${file}
    for release in $(find docs/releases/ -type f | grep -v rc | sort -Vr); do
        cat ${release} >> ${file}
        echo "" >> ${file}
    done
    read -p "Are you sure you want to do a commit for the changelog? [y/N] " confirm
    if [[ ${confirm} != "Y" ]]; then
        exit 1
    fi

    git add -A
    git commit -m "Release ${FULL_VERSION}"
}

build_artifacts() {
    make ignite
    make ignite-spawn
    mkdir -p bin/releases/${FULL_VERSION}
    cp bin/ignite bin/releases/${FULL_VERSION}
    make -C images build-all
}